@@ -27,19 +27,22 @@ SEXP calcDisSimMat(SEXP fileName, SEXP nSweeps, SEXP nBurn, SEXP nFilter,SEXP nS
     bool oLS = Rcpp::as<bool>(onlyLS);
 
     // Calculate how many samples we will have
-    unsigned int nLines = 1 + (nS+nB)/nF;
+    unsigned int nLines =  (nS+nB)/nF;
     // Calculate when the burn in ends
-    unsigned int firstLine = 2+nB/nF;
+    unsigned int firstLine = nB/nF;
 
-    vector<double> disSimMat((nSj*(nSj-1))/2+nPSj*nSj,1.0);
+    // The denominator for the contributions
+    double denom = (double)nLines-(double)firstLine;
+
+	// Number of entries in diagonal dissimilarity matrix matrix
+	unsigned long int lengthMat = (nSj*(nSj-1))/2+nPSj*nSj;
+	
+    vector<double> disSimMat(lengthMat,denom);
 
     // Open the file with sample in
     ifstream zFile;
     zFile.open(fName.c_str());
 
-    // The denominator for the contributions
-    double denom = 1+(double)nLines-(double)firstLine;
-
     // A temporary vector for storing the cluster from each sweep
     vector<int> clusterData(nSj+nPSj);
     for(unsigned long int k=1;k<=nLines;k++){
@@ -62,7 +65,7 @@ SEXP calcDisSimMat(SEXP fileName, SEXP nSweeps, SEXP nBurn, SEXP nFilter,SEXP nS
 		for(unsigned long int i=0;i<nSj-1;i++){
     			for(unsigned long int ii=i+1;ii<nSj;ii++){
     				if(clusterData[i]==clusterData[ii]){
-        				disSimMat[r]-=1.0/denom;
+        				disSimMat[r]-=1.0;
         			}
     				r++;
     			}
@@ -70,13 +73,15 @@ SEXP calcDisSimMat(SEXP fileName, SEXP nSweeps, SEXP nBurn, SEXP nFilter,SEXP nS
 		for(unsigned long int i=0;i<nPSj;i++){
 			for(unsigned long int ii=0;ii<nSj;ii++){
 				if(clusterData[nSj+i]==clusterData[ii]){
-					disSimMat[r]-=1.0/denom;
+					disSimMat[r]-=1.0;
 				}
 				r++;
 			}
 		}
     	}
     }
+	for (unsigned long int i=0;i<lengthMat;i++) disSimMat[i] /= denom;
+	
 
     // Computing the optimal partition for least squares method 
     // Could make these steps optional as only relevant for R option useLS=T
